@@ -56,6 +56,7 @@ __all__ = [
 class _Nxlib():
     def __init__(self):
         self.is_remote = False
+        self.is_connected = False
         self.lib_object = None
         atexit.register(self.reset)
 
@@ -183,6 +184,7 @@ def load_remote_lib(path=None):
     else:
         _nxlib.lib_object = CDLL(path)
     _nxlib.is_remote = True
+    _nxlib.is_connected = False
     if _nxlib.lib_object is None:
         raise NxLibError("Could not load shared remote library")
 
@@ -191,6 +193,8 @@ def _check_return_code(path="", return_code=c_int32(0)):
     if isinstance(return_code, c_int32):
         return_code = return_code.value
     if return_code != NXLIB_OPERATION_SUCCEEDED:
+        if isinstance(path, bytes):
+            path = path.decode()
         raise NxLibException(path, return_code)
 
 
@@ -725,6 +729,7 @@ def connect(hostname, port):
     hostname = helper.fix_string_encoding(hostname)
     f(byref(return_code), hostname, port)
     _check_return_code(return_code=return_code)
+    _nxlib.is_connected = True
 
 
 def disconnect():
@@ -744,3 +749,4 @@ def disconnect():
     return_code = c_int32(0)
     f(byref(return_code))
     _check_return_code(return_code=return_code)
+    _nxlib.is_connected = False
