@@ -1,6 +1,6 @@
 import nxlib.api as api
 from nxlib.constants import *
-from nxlib.exception import NxLibException, _handle_exception
+from nxlib.exception import NxLibException
 from nxlib.item import NxLibItem
 
 __all__ = ["NxLibCommand"]
@@ -31,14 +31,7 @@ class NxLibCommand:
         else:
             self._command_item = NxLibItem()[ITM_EXECUTE][node_name]
 
-        self._set_parameters(self.parameters(), params)
-
-    def _set_parameters(self, node, params):
-        for key, value in params.items():
-            if type(value) != dict:
-                node[key] = value
-            else:
-                self._set_parameters(node[key], value)
+        self.parameters() << params
 
     def _belongs_to_current_lib(self):
         return self._nxlib_id == api._nxlib_id
@@ -46,7 +39,8 @@ class NxLibCommand:
     def _remove_slot(self):
         if self._remove_slot_on_destruction and self._belongs_to_current_lib():
             try:
-                self._command_item.erase()
+                if not api.is_current_lib_remote() or api._nxlib.is_connected:
+                    self._command_item.erase()
             except NxLibException as e:
                 if e.get_error_code() == NXLIB_INITIALIZATION_NOT_ALLOWED:
                     pass
@@ -55,14 +49,23 @@ class NxLibCommand:
         self._remove_slot_on_destruction = False
 
     def __del__(self):
-        self._remove_slot()
+        try:
+            self._remove_slot()
+        except Exception:
+            # The destructor might be called after some of the required modules
+            # have already been unloaded. Ignore any errors this might cause.
+            pass
 
     def __enter__(self):
         return self
 
     def __exit__(self, exc_type, exc_value, exc_tb):
-        self._remove_slot()
-        return _handle_exception(exc_type, exc_value, exc_tb)
+        # We keep the slot if an exception occured within the context, because
+        # the command is referenced by the exception and might be used for error
+        # investigation. The command destruction is eventually triggered after
+        # the exception gets destroyed.
+        if exc_type is None:
+            self._remove_slot()
 
     def _create_temporary_slot(self, base_name=None):
         self._command_item = NxLibItem()[ITM_EXECUTE].make_unique_item(
@@ -127,8 +130,7 @@ class NxLibCommand:
         function_item.set_string(command_name)
 
         if wait:
-            function_item.wait_for_type(NXLIB_ITEM_TYPE_NULL, True)
-            self.assert_successful()
+            self.wait()
 
     def finished(self):
         """
@@ -141,6 +143,19 @@ class NxLibCommand:
         cmd_node = self.slot()[ITM_COMMAND]
         return (not cmd_node.exists() or cmd_node.is_null())
 
+    def wait(self):
+        """
+        Waits for the command execution to finish.
+
+        Raises:
+            NxLibException: If the command execution was not successful.
+        """
+        function_item = self.slot()[ITM_COMMAND]
+        if not function_item.exists():
+            return
+        function_item.wait_for_type(NXLIB_ITEM_TYPE_NULL, True)
+        self.assert_successful()
+
     def assert_successful(self):
         """
         Checks whether the previous command execution is finished and was
