@@ -1,6 +1,6 @@
 NXLIB_ITEM_SEPARATOR = "/"
 NXLIB_INDEX_ESCAPE_CHAR = "\\"
-NXLIB_ITEM_FORBIDDEN_CHARS = "\r\n\"/\\\0"
+NXLIB_ITEM_FORBIDDEN_CHARS = "\t \b\a\r\n\"/\\\0"
 NX_LOG_LEVELS = {"Off": 0, "Info": 1, "Debug": 2, "Trace": 3}
 NX_LOG_LEVEL_OFF = "Off"
 NX_LOG_LEVEL_INFO = "Info"
@@ -12,15 +12,12 @@ CMD_ADJUST_EXPOSURE_AND_GAIN = "AdjustExposureAndGain"
 CMD_BREAK = "Break"
 CMD_CALIBRATE = "Calibrate"
 CMD_CALIBRATE_HAND_EYE = "CalibrateHandEye"
-CMD_CALIBRATE_IN_BACKGROUND = "CalibrateInBackground"
 CMD_CALIBRATE_LASER_PROJECTOR = "CalibrateLaserProjector"
 CMD_CALIBRATE_PATTERN = "CalibratePattern"
-CMD_CALIBRATE_UPDATE_PATTERNS = "CalibrateUpdatePatterns"
 CMD_CALIBRATE_WORKSPACE = "CalibrateWorkspace"
 CMD_CAPTURE = "Capture"
 CMD_CHAIN_TRANSFORMATIONS = "ChainTransformations"
 CMD_CLEAR_IMAGE_BUFFER = "ClearImageBuffer"
-CMD_CLEAR_IMAGES = "ClearImages"
 CMD_CLEAR_OVERLAY = "ClearOverlay"
 CMD_CLOSE = "Close"
 CMD_COLLECT_LASER_POINTS = "CollectLaserPoints"
@@ -31,12 +28,16 @@ CMD_COMPUTE_IMAGE_CONTRAST = "ComputeImageContrast"
 CMD_COMPUTE_NORMALS = "ComputeNormals"
 CMD_COMPUTE_POINT_MAP = "ComputePointMap"
 CMD_COMPUTE_TEXTURE = "ComputeTexture"
+CMD_CONFIGURE_IP = "ConfigureIp"
 CMD_CONVERT_TRANSFORMATION = "ConvertTransformation"
 CMD_CREATE_CAMERA = "CreateCamera"
+CMD_CREATE_FILE_CAMERA = "CreateFileCamera"
 CMD_DELETE_CAMERA = "DeleteCamera"
 CMD_DISCARD_LASER_POINTS = "DiscardLaserPoints"
 CMD_DISCARD_PATTERNS = "DiscardPatterns"
+CMD_DISTRIBUTE_BANDWIDTH = "DistributeBandwidth"
 CMD_DOWNLOAD_IMAGES = "DownloadImages"
+CMD_ESTIMATE_CAPTURE_TIMEOUT = "EstimateCaptureTimeout"
 CMD_ESTIMATE_DISPARITY_SETTINGS = "EstimateDisparitySettings"
 CMD_ESTIMATE_PATTERN_POSE = "EstimatePatternPose"
 CMD_ETHERNET_CONFIGURATION = "EthernetConfiguration"
@@ -45,9 +46,11 @@ CMD_FIT_PRIMITIVE = "FitPrimitive"
 CMD_FLASH = "Flash"
 CMD_GENERATE_CALIBRATION_PATTERN = "GenerateCalibrationPattern"
 CMD_GET_CONSTANTS = "GetConstants"
+CMD_GET_DOCUMENTATION = "GetDocumentation"
 CMD_GET_MODEL_INFO = "GetModelInfo"
 CMD_GET_PATTERN_BUFFER = "GetPatternBuffer"
 CMD_GET_PATTERN_BUFFERS = "GetPatternBuffers"
+CMD_GET_PRESETS = "GetPresets"
 CMD_GET_RAW_CALIBRATION_DATA = "GetRawCalibrationData"
 CMD_INTERNAL_PWM = "InternalPwm"
 CMD_LOAD_CALIBRATION = "LoadCalibration"
@@ -58,12 +61,14 @@ CMD_LOAD_U_EYE_PARAMETER_SET = "LoadUEyeParameterSet"
 CMD_LOOP = "Loop"
 CMD_MEASURE_CALIBRATION = "MeasureCalibration"
 CMD_MEASURE_LASER_CALIBRATION = "MeasureLaserCalibration"
+CMD_NAVIGATE_VIEW = "NavigateView"
 CMD_NETWORK_CONTROL = "NetworkControl"
 CMD_OPEN = "Open"
 CMD_PART_FINDER = "PartFinder"
 CMD_PATTERN_BUFFER_INFO = "PatternBufferInfo"
 CMD_PROJECT_PATTERN = "ProjectPattern"
 CMD_PROJECT_POINTS = "ProjectPoints"
+CMD_QUERY_RENDER_VIEW = "QueryRenderView"
 CMD_READ_EEPROM = "ReadEeprom"
 CMD_RECALIBRATE = "Recalibrate"
 CMD_RECTIFY_IMAGES = "RectifyImages"
@@ -75,10 +80,14 @@ CMD_RENDER_DEPTH_MAP = "RenderDepthMap"
 CMD_RENDER_POINT_MAP = "RenderPointMap"
 CMD_RENDER_VIEW = "RenderView"
 CMD_REPROJECT_POINTS = "ReprojectPoints"
+CMD_RESET_DEVICE = "ResetDevice"
 CMD_RETRIEVE = "Retrieve"
+CMD_SAVE_CAMERA_MODEL = "SaveCameraModel"
+CMD_SAVE_FILE_CAMERA = "SaveFileCamera"
 CMD_SAVE_IMAGE = "SaveImage"
 CMD_SAVE_LASER_POINTS = "SaveLaserPoints"
 CMD_SAVE_MODEL = "SaveModel"
+CMD_SAVE_PARAMETERS = "SaveParameters"
 CMD_SAVE_TEXT = "SaveText"
 CMD_SET_PATTERN_BUFFER = "SetPatternBuffer"
 CMD_SET_PATTERN_BUFFERS = "SetPatternBuffers"
@@ -93,29 +102,77 @@ CMD_VISUALIZE_LASER_POINTS = "VisualizeLaserPoints"
 CMD_VISUALIZE_PATTERN_BUFFER = "VisualizePatternBuffer"
 CMD_WIFI = "Wifi"
 CMD_WRITE_EEPROM = "WriteEeprom"
+ERR_BUFFER_OVERRUN = "BufferOverrun"
+ERR_CUDA_OUT_OF_MEMORY = "CUDAOutOfMemory"
+ERR_CUDA_UNSUPPORTED_DRIVER = "CUDAUnsupportedDriver"
 ERR_CALIBRATION_FAILED = "CalibrationFailed"
 ERR_CAMERA_NOT_FOUND = "CameraNotFound"
+ERR_CAPTURE_CANCEL = "CaptureCancel"
+ERR_CAPTURE_SUCCESSFUL = "CaptureSuccessful"
+ERR_CAPTURE_TIMEOUT = "CaptureTimeout"
 ERR_CHANGED_MODEL = "ChangedModel"
 ERR_COMMAND_NOT_ALLOWED = "CommandNotAllowed"
 ERR_COMMAND_UNKNOWN = "CommandUnknown"
+ERR_CONVERSATION_FAILED = "ConversationFailed"
+ERR_DEVICE_CAPTURE_FAILED = "DeviceCaptureFailed"
+ERR_DEVICE_NOT_READY = "DeviceNotReady"
+ERR_DEVICE_TIMEOUT = "DeviceTimeout"
+ERR_DISCARDED_IMAGE = "DiscardedImage"
+ERR_EEPROM_UPGRADE_NEEDED = "EepromUpgradeNeeded"
 ERR_EMPTY_IMAGE = "EmptyImage"
 ERR_EMPTY_POINT_MAP = "EmptyPointMap"
+ERR_ENSENSO_CAL_TAB = "EnsensoCalTab"
+ERR_EVENT_BUFFER_OVERFLOW = "EventBufferOverflow"
+ERR_FILE_IO = "FileIO"
+ERR_FUNCTION_NOT_SUPPORTED = "FunctionNotSupported"
+ERR_GL_DRIVER = "GLDriver"
+ERR_IMAGE_LOCKED = "ImageLocked"
+ERR_IMAGE_TRANSFER_FAILED = "ImageTransferFailed"
+ERR_INTERNAL_ERROR = "InternalError"
+ERR_INVALID_CALIBRATION_DATA = "InvalidCalibrationData"
+ERR_INVALID_GRID_SPACING = "InvalidGridSpacing"
+ERR_INVALID_IP_CONFIG = "InvalidIpConfig"
+ERR_INVALID_OPERATION = "InvalidOperation"
+ERR_INVALID_PAIRING_DATA = "InvalidPairingData"
 ERR_INVALID_PATTERN_BUFFER = "InvalidPatternBuffer"
+ERR_MISSED_IMAGES = "MissedImages"
+ERR_MISSING_FIRMWARE = "MissingFirmware"
+ERR_NESTING_LIMIT_REACHED = "NestingLimitReached"
+ERR_NO_DESTINATION_MEMORY = "NoDestinationMemory"
+ERR_NO_LICENSE = "NoLicense"
+ERR_NO_OPEN_PROFILE_BLOCK = "NoOpenProfileBlock"
 ERR_NO_WORKSPACE_LINK = "NoWorkspaceLink"
 ERR_NOT_ENOUGH_POINTS_FOR_PRIMITIVE = "NotEnoughPointsForPrimitive"
+ERR_NOT_SUPPORTED = "NotSupported"
 ERR_OPERATION_CANCELED = "OperationCanceled"
+ERR_OUT_OF_BUFFERS = "OutOfBuffers"
+ERR_PARAMETERS_INVALID = "ParametersInvalid"
 ERR_PATTERN_BUFFER_LOCKED = "PatternBufferLocked"
 ERR_PATTERN_DATA_INCOMPATIBLE = "PatternDataIncompatible"
 ERR_PATTERN_NOT_DECODABLE = "PatternNotDecodable"
 ERR_PATTERN_NOT_FOUND = "PatternNotFound"
+ERR_PROFILE_DESERIALIZATION_FAILED = "ProfileDeserializationFailed"
+ERR_PROJECTOR_APPLICATION_END_FAILED = "ProjectorApplicationEndFailed"
+ERR_PROJECTOR_APPLICATION_START_FAILED = "ProjectorApplicationStartFailed"
+ERR_PROJECTOR_APPLICATION_UPLOAD_FAILED = "ProjectorApplicationUploadFailed"
+ERR_PROJECTOR_NO_APPLICATION = "ProjectorNoApplication"
+ERR_PROJECTOR_SIGNATURE = "ProjectorSignature"
+ERR_PROJECTOR_TIMEOUT = "ProjectorTimeout"
+ERR_PROJECTOR_UNKNOWN_TEMPERATURE_SENSOR = "ProjectorUnknownTemperatureSensor"
+ERR_RING_BUFFER_INDEX = "RingBufferIndex"
 ERR_SENSOR_NOT_COMPATIBLE = "SensorNotCompatible"
+ERR_TERMINATION_REQUESTED = "TerminationRequested"
 ERR_UNHANDLED_EXCEPTION = "UnhandledException"
+ERR_UNKNOWN_CAPTURE_STATUS = "UnknownCaptureStatus"
+ERR_UNKNOWN_U_EYE_CAPTURE_STATUS = "UnknownUEyeCaptureStatus"
 ERR_WIRING_TEST_FAILED = "WiringTestFailed"
 ITM_ABSOLUTE_BLACK_LEVEL_OFFSET = "AbsoluteBlackLevelOffset"
 ITM_ACCESS_POINT = "AccessPoint"
 ITM_ACCESS_POINTS = "AccessPoints"
+ITM_ACTION_REQUIRED = "ActionRequired"
 ITM_ACTIVE = "Active"
 ITM_ADAPTERS = "Adapters"
+ITM_ADDRESS = "Address"
 ITM_ADJUST_EXPOSURE = "AdjustExposure"
 ITM_ADJUST_GAIN = "AdjustGain"
 ITM_ALIGN_AXIS = "AlignAxis"
@@ -123,6 +180,7 @@ ITM_ALL = "All"
 ITM_ALLOW_FIRMWARE_UPLOAD = "AllowFirmwareUpload"
 ITM_ALPHA = "Alpha"
 ITM_AMBIENT = "Ambient"
+ITM_ANCHOR = "Anchor"
 ITM_AND = "And"
 ITM_ANGLE = "Angle"
 ITM_ANGLES = "Angles"
@@ -131,11 +189,13 @@ ITM_APERTURE = "Aperture"
 ITM_API_ERRORS = "ApiErrors"
 ITM_APPLICATION = "Application"
 ITM_APPLY = "Apply"
+ITM_APPROVED = "Approved"
 ITM_ARCHITECTURE = "Architecture"
 ITM_AREA_OF_INTEREST = "AreaOfInterest"
 ITM_ASSEMBLY_CALIBRATION = "AssemblyCalibration"
 ITM_ASSEMBLY_PATTERN = "AssemblyPattern"
 ITM_ASYNCHRONOUSLY_TRIGGERED = "AsynchronouslyTriggered"
+ITM_ATTENTION_REGIONS = "AttentionRegions"
 ITM_AUTO_BLACK_LEVEL = "AutoBlackLevel"
 ITM_AUTO_EXPOSURE = "AutoExposure"
 ITM_AUTO_FOCUS = "AutoFocus"
@@ -146,19 +206,25 @@ ITM_AVAILABLE = "Available"
 ITM_AVERAGE = "Average"
 ITM_AVERAGE_POSE_ERROR = "AveragePoseError"
 ITM_AVERAGE_TRIANGULATION_ERROR = "AverageTriangulationError"
+ITM_AVX2 = "Avx2"
+ITM_AXES = "Axes"
 ITM_AXIS = "Axis"
 ITM_BACKGROUND = "Background"
+ITM_BACKLOG_SIZE = "BacklogSize"
 ITM_BANDWIDTH = "Bandwidth"
 ITM_BANDWIDTH_LIMIT = "BandwidthLimit"
 ITM_BASELINE = "Baseline"
+ITM_BASELINES = "Baselines"
 ITM_BETA = "Beta"
 ITM_BILLBOARD_SIZE = "BillboardSize"
+ITM_BINARIES = "Binaries"
 ITM_BINARY_INFO = "BinaryInfo"
 ITM_BINNING = "Binning"
 ITM_BINNING_SHIFT = "BinningShift"
 ITM_BLACK_LEVEL_OFFSET = "BlackLevelOffset"
 ITM_BLACK_LEVEL_OFFSET_CALIBRATION = "BlackLevelOffsetCalibration"
 ITM_BLIND = "Blind"
+ITM_BLUE = "Blue"
 ITM_BLUR = "Blur"
 ITM_BLUR_MIN_MAX = "BlurMinMax"
 ITM_BOARD = "Board"
@@ -169,8 +235,8 @@ ITM_BRANCH = "Branch"
 ITM_BRIGHTNESS = "Brightness"
 ITM_BUFFER = "Buffer"
 ITM_BUFFER_COUNT = "BufferCount"
-ITM_BUFFER_SIZE = "BufferSize"
 ITM_BUILD = "Build"
+ITM_BUILD_TYPE = "BuildType"
 ITM_BY_EEPROM_ID = "ByEepromId"
 ITM_BY_SERIAL_NO = "BySerialNo"
 ITM_CPU = "CPU"
@@ -187,21 +253,28 @@ ITM_CALIBRATION_FILE = "CalibrationFile"
 ITM_CALIBRATION_HISTORY = "CalibrationHistory"
 ITM_CALIBRATION_TARGET = "CalibrationTarget"
 ITM_CAMERA = "Camera"
+ITM_CAMERA_POSE = "CameraPose"
 ITM_CAMERAS = "Cameras"
+ITM_CAPTION = "Caption"
 ITM_CAPTURE = "Capture"
 ITM_CAPTURE_EVENTS = "CaptureEvents"
 ITM_CENTER = "Center"
 ITM_CHANNEL = "Channel"
+ITM_CHANNELS = "Channels"
 ITM_CHECK = "Check"
 ITM_CHECK_DAEMON = "CheckDaemon"
+ITM_CIRCLE = "Circle"
 ITM_CLEAR_IMAGE_BUFFER_ON_TRIGGER = "ClearImageBufferOnTrigger"
+ITM_CLI = "Cli"
 ITM_CLIENT = "Client"
 ITM_CLIP_TO_AREA_OF_INTEREST = "ClipToAreaOfInterest"
 ITM_CLOCK_RATE = "ClockRate"
 ITM_CLUSTER = "Cluster"
 ITM_CODE_METER = "CodeMeter"
 ITM_COLOR = "Color"
+ITM_COLOR_MAP = "ColorMap"
 ITM_COLOR_OFFSET = "ColorOffset"
+ITM_COLOR_PROPORTION = "ColorProportion"
 ITM_COLOR_REPETITION_DISTANCE = "ColorRepetitionDistance"
 ITM_COLORING_MODE = "ColoringMode"
 ITM_COMBINED_SCORE = "CombinedScore"
@@ -209,18 +282,24 @@ ITM_COMMAND = "Command"
 ITM_COMMANDS = "Commands"
 ITM_COMMON_ITEMS = "CommonItems"
 ITM_COMMON_VALUES = "CommonValues"
+ITM_COMPLEMENT_VIEWPOINTS = "ComplementViewpoints"
 ITM_COMPONENT_THRESHOLD = "ComponentThreshold"
+ITM_COMPONENTS = "Components"
 ITM_COMPRESS_MODEL = "CompressModel"
 ITM_COMPUTE_CAPABILITY = "ComputeCapability"
 ITM_COMPUTE_DISPARITY_MAP = "ComputeDisparityMap"
+ITM_CONDITION = "Condition"
 ITM_CONFIGURATION = "Configuration"
 ITM_CONNECTED = "Connected"
 ITM_CONNECTED_CAMERAS = "ConnectedCameras"
 ITM_CONNECTED_PATTERNS = "ConnectedPatterns"
 ITM_CONTENT = "Content"
 ITM_CONTRAST = "Contrast"
+ITM_CONVENTION = "Convention"
+ITM_COORDINATES = "Coordinates"
 ITM_CORES = "Cores"
 ITM_CORNERS = "Corners"
+ITM_CORRELATION = "Correlation"
 ITM_CORRESPONDENCE_THRESHOLD = "CorrespondenceThreshold"
 ITM_COST_SCALE = "CostScale"
 ITM_COUNT = "Count"
@@ -228,9 +307,12 @@ ITM_COUPLED_PROPAGATION = "CoupledPropagation"
 ITM_COVERAGE = "Coverage"
 ITM_COVERAGE_DISTANCE_THRESHOLD = "CoverageDistanceThreshold"
 ITM_COVERAGE_SCORE = "CoverageScore"
+ITM_CROP_REGIONS = "CropRegions"
 ITM_CURRENT = "Current"
 ITM_DHCP = "DHCP"
 ITM_DATA = "Data"
+ITM_DATA_MATCHES = "DataMatches"
+ITM_DATA_SOURCE = "DataSource"
 ITM_DAY = "Day"
 ITM_DEBUG = "Debug"
 ITM_DECODE_DATA = "DecodeData"
@@ -240,8 +322,9 @@ ITM_DEFAULT_PARAMETERS = "DefaultParameters"
 ITM_DEFINED_POSE = "DefinedPose"
 ITM_DEPTH = "Depth"
 ITM_DEPTH_CHANGE_COST = "DepthChangeCost"
+ITM_DEPTH_GRADIENT = "DepthGradient"
 ITM_DEPTH_STEP_COST = "DepthStepCost"
-ITM_DESTINATION = "Destination"
+ITM_DESCRIPTION = "Description"
 ITM_DEVICE = "Device"
 ITM_DEVICES = "Devices"
 ITM_DIFFUSE = "Diffuse"
@@ -274,6 +357,7 @@ ITM_ENABLE_IP_FILTER = "EnableIpFilter"
 ITM_ENABLED = "Enabled"
 ITM_ENCODING = "Encoding"
 ITM_ENFORCE_DISPARITY_RANGE = "EnforceDisparityRange"
+ITM_ENGAGE = "Engage"
 ITM_EPIPOLAR = "Epipolar"
 ITM_EPIPOLAR_ERROR = "EpipolarError"
 ITM_ERROR_SYMBOL = "ErrorSymbol"
@@ -283,13 +367,17 @@ ITM_ESTIMATE_GRID_SPACING = "EstimateGridSpacing"
 ITM_ETHERNET = "Ethernet"
 ITM_ETHERNET_CONFIG_MODE = "EthernetConfigMode"
 ITM_EXCLUDE_OBJECTS = "ExcludeObjects"
+ITM_EXCLUDED_PRESETS = "ExcludedPresets"
 ITM_EXECUTE = "Execute"
 ITM_EXPOSURE = "Exposure"
 ITM_EXT = "Ext"
 ITM_EXTENDED_TYPE = "ExtendedType"
+ITM_EXTENDS = "Extends"
+ITM_EXTRINSIC = "Extrinsic"
 ITM_FACTORY = "Factory"
 ITM_FAILURE_PROBABILITY = "FailureProbability"
 ITM_FAR = "Far"
+ITM_FEATURE = "Feature"
 ITM_FILE_OUTPUT = "FileOutput"
 ITM_FILE_PREFIX = "FilePrefix"
 ITM_FILENAME = "Filename"
@@ -299,6 +387,8 @@ ITM_FILTER = "Filter"
 ITM_FILTERS = "Filters"
 ITM_FINAL_TRIGGER = "FinalTrigger"
 ITM_FIND = "Find"
+ITM_FIREFLY_THRESHOLD = "FireflyThreshold"
+ITM_FIRMWARE = "Firmware"
 ITM_FIRMWARE_SUPPORTS_MODEL = "FirmwareSupportsModel"
 ITM_FIRMWARE_UPDATE_VERSION = "FirmwareUpdateVersion"
 ITM_FIRMWARE_UPLOAD = "FirmwareUpload"
@@ -311,29 +401,40 @@ ITM_FOCAL_LENGTH = "FocalLength"
 ITM_FOCUS = "Focus"
 ITM_FOCUS_DISTANCE = "FocusDistance"
 ITM_FOLDER_PATH = "FolderPath"
+ITM_FOLLOW = "Follow"
 ITM_FOLLOW_DYNAMIC_OFFSETS = "FollowDynamicOffsets"
 ITM_FONT = "Font"
 ITM_FORCE = "Force"
 ITM_FORCE_GRAYSCALE = "ForceGrayscale"
 ITM_FORCED_RAW_IMAGE_SIZE = "ForcedRawImageSize"
 ITM_FORCED_RECTIFIED_IMAGE_SIZE = "ForcedRectifiedImageSize"
+ITM_FORMAT = "Format"
+ITM_FOUND = "Found"
 ITM_FREQUENCY = "Frequency"
 ITM_FROM_DYNAMIC = "FromDynamic"
 ITM_FRONT_LIGHT = "FrontLight"
+ITM_FRONT_LIGHT_POWER = "FrontLightPower"
+ITM_FRUSTUM = "Frustum"
 ITM_FULL_WIDTH = "FullWidth"
 ITM_FUNCTION = "Function"
 ITM_GAIN = "Gain"
 ITM_GAIN_BOOST = "GainBoost"
 ITM_GATEWAY = "Gateway"
 ITM_GENERATE_EMPTY_CALIBRATION = "GenerateEmptyCalibration"
+ITM_GENERATE_MODEL = "GenerateModel"
 ITM_GLOBAL_PATTERN_DATA_UPDATED = "GlobalPatternDataUpdated"
 ITM_GLOBAL_SHUTTER = "GlobalShutter"
 ITM_GLOW = "Glow"
+ITM_GRADIENT = "Gradient"
 ITM_GRAVITY = "Gravity"
+ITM_GRAY_GRADIENT = "GrayGradient"
 ITM_GREEN = "Green"
+ITM_GRID = "Grid"
 ITM_GRID_SIZE = "GridSize"
 ITM_GRID_SPACING = "GridSpacing"
 ITM_GROUND_PLANE = "GroundPlane"
+ITM_GROUP = "Group"
+ITM_GROUPS = "Groups"
 ITM_HUD = "HUD"
 ITM_HALF_VERGENCE = "HalfVergence"
 ITM_HARDWARE_FAILURE = "HardwareFailure"
@@ -344,13 +445,17 @@ ITM_HASH = "Hash"
 ITM_HDR = "Hdr"
 ITM_HEATER = "Heater"
 ITM_HEIGHT = "Height"
+ITM_HIDDEN = "Hidden"
 ITM_HIGH_QUALITY_RENDERING = "HighQualityRendering"
 ITM_HORIZONTAL = "Horizontal"
+ITM_HOST = "Host"
 ITM_HYPOTHESIS = "Hypothesis"
 ITM_IO = "IO"
+ITM_IGNORE_INSTALLED = "IgnoreInstalled"
 ITM_IGNORED_ERROR_SYMBOLS = "IgnoredErrorSymbols"
 ITM_IMAGE_BUFFER = "ImageBuffer"
 ITM_IMAGE_DOWNLOAD_LIMIT = "ImageDownloadLimit"
+ITM_IMAGE_ENHANCEMENT = "ImageEnhancement"
 ITM_IMAGE_FOLDER = "ImageFolder"
 ITM_IMAGE_NAME = "ImageName"
 ITM_IMAGE_OFFSET = "ImageOffset"
@@ -360,7 +465,6 @@ ITM_IMAGES = "Images"
 ITM_IN_PLANE_ANGULAR_RESOLUTION = "InPlaneAngularResolution"
 ITM_INDEX = "Index"
 ITM_INFO = "Info"
-ITM_INFO_TIMEOUT = "InfoTimeout"
 ITM_INITIAL_TRIGGER = "InitialTrigger"
 ITM_INITIAL_VELOCITY = "InitialVelocity"
 ITM_INLIER_COUNT = "InlierCount"
@@ -370,13 +474,16 @@ ITM_INPUT = "Input"
 ITM_INTEGRATED = "Integrated"
 ITM_INTERFACE = "Interface"
 ITM_INTERNAL_TRIGGER = "InternalTrigger"
+ITM_INTERRUPT = "Interrupt"
 ITM_INTERVAL = "Interval"
 ITM_INVALIDATION = "Invalidation"
 ITM_INVERSE = "Inverse"
 ITM_INVERT = "Invert"
 ITM_IP_ADDRESS = "IpAddress"
 ITM_IP_BROADCAST = "IpBroadcast"
+ITM_IP_CONFIGURATION = "IpConfiguration"
 ITM_IP_SUBNET_MASK = "IpSubnetMask"
+ITM_IS_APPROVED_FIRMWARE_VERSION = "IsApprovedFirmwareVersion"
 ITM_IS_SUPPLIED_FIRMWARE_VERSION = "IsSuppliedFirmwareVersion"
 ITM_ITEM_TYPES = "ItemTypes"
 ITM_ITEMS = "Items"
@@ -386,11 +493,13 @@ ITM_K2 = "K2"
 ITM_K3 = "K3"
 ITM_KEEP_ALIVE_TIMEOUT = "KeepAliveTimeout"
 ITM_LED = "LED"
+ITM_LARGE_CORRELATION_WINDOW = "LargeCorrelationWindow"
 ITM_LATEST = "Latest"
 ITM_LATEST_MESSAGE = "LatestMessage"
 ITM_LEFT = "Left"
 ITM_LEFT_BOTTOM = "LeftBottom"
 ITM_LEFT_TOP = "LeftTop"
+ITM_LENGTH = "Length"
 ITM_LENS = "Lens"
 ITM_LENSES = "Lenses"
 ITM_LEVEL = "Level"
@@ -410,8 +519,9 @@ ITM_LOW_BANDWIDTH = "LowBandwidth"
 ITM_MAC = "MAC"
 ITM_MAC_ADDRESSES = "MacAddresses"
 ITM_MAJOR = "Major"
-ITM_MARK_FILTER_REGIONS = "MarkFilterRegions"
+ITM_MANUAL = "Manual"
 ITM_MARK_ONLY = "MarkOnly"
+ITM_MARKERS = "Markers"
 ITM_MASK = "Mask"
 ITM_MASS = "Mass"
 ITM_MASTER = "Master"
@@ -426,6 +536,7 @@ ITM_MAX_POSE_ERROR = "MaxPoseError"
 ITM_MAX_TOTAL_SIZE = "MaxTotalSize"
 ITM_MAX_TRIANGULATION_ERROR = "MaxTriangulationError"
 ITM_MAXIMUM_CLUSTER_SIZE = "MaximumClusterSize"
+ITM_MAXIMUM_DEPTH = "MaximumDepth"
 ITM_MAXIMUM_SPREAD_ORDER = "MaximumSpreadOrder"
 ITM_MAXIMUM_TRANSMISSION_UNIT = "MaximumTransmissionUnit"
 ITM_MEASURE_CALIBRATION = "MeasureCalibration"
@@ -440,14 +551,19 @@ ITM_META_INFO = "MetaInfo"
 ITM_METHOD = "Method"
 ITM_MIN = "Min"
 ITM_MIN_DISPARITY = "MinDisparity"
+ITM_MINIMAL_ANGLES = "MinimalAngles"
 ITM_MINIMUM_ASPECT_RATIO = "MinimumAspectRatio"
+ITM_MINIMUM_DEPTH = "MinimumDepth"
 ITM_MINIMUM_DISPARITY = "MinimumDisparity"
 ITM_MINIMUM_LEADING_SCORE = "MinimumLeadingScore"
 ITM_MINIMUM_POINT_RATIO = "MinimumPointRatio"
+ITM_MINIMUM_PROBABILITY = "MinimumProbability"
 ITM_MINIMUM_SPREAD_ORDER = "MinimumSpreadOrder"
 ITM_MINIMUM_VOLTAGE = "MinimumVoltage"
 ITM_MINOR = "Minor"
 ITM_MIRROR = "Mirror"
+ITM_MIX_COLOR_WITH_TEXTURE = "MixColorWithTexture"
+ITM_MODALITIES = "Modalities"
 ITM_MODE = "Mode"
 ITM_MODEL = "Model"
 ITM_MODEL_ID = "ModelId"
@@ -459,12 +575,14 @@ ITM_MONOCULAR = "Monocular"
 ITM_MONOCULAR_CALIBRATION = "MonocularCalibration"
 ITM_MONOCULAR_PATTERN_COUNT = "MonocularPatternCount"
 ITM_MONTH = "Month"
+ITM_MOVE = "Move"
 ITM_MULTI_EXPOSURE_FACTOR = "MultiExposureFactor"
 ITM_NAME = "Name"
 ITM_NEAR = "Near"
 ITM_NETWORK_ADAPTER = "NetworkAdapter"
 ITM_NETWORK_ADAPTER_IP_ADDRESS = "NetworkAdapterIpAddress"
 ITM_NETWORK_ADAPTER_IP_SUBNET_MASK = "NetworkAdapterIpSubnetMask"
+ITM_NETWORK_CONNECTION = "NetworkConnection"
 ITM_NODE = "Node"
 ITM_NODES = "Nodes"
 ITM_NOISE_LEVEL = "NoiseLevel"
@@ -473,6 +591,9 @@ ITM_NORMALS = "Normals"
 ITM_NUMBER_OF_DISPARITIES = "NumberOfDisparities"
 ITM_NUMBER_OF_IMAGE_SETS = "NumberOfImageSets"
 ITM_NX_LIB = "NxLib"
+ITM_NX_TREE_EDIT = "NxTreeEdit"
+ITM_NX_VIEW = "NxView"
+ITM_OBJECT = "Object"
 ITM_OBJECT_POINTS = "ObjectPoints"
 ITM_OBJECTS = "Objects"
 ITM_OFFSET = "Offset"
@@ -480,19 +601,22 @@ ITM_OPACITY = "Opacity"
 ITM_OPEN = "Open"
 ITM_OPEN_MP = "OpenMP"
 ITM_OPERATING_SYSTEM = "OperatingSystem"
-ITM_OPERATION = "Operation"
 ITM_OPTICAL_AXIS = "OpticalAxis"
 ITM_OPTIMAL_FILTER_SIZE = "OptimalFilterSize"
 ITM_OPTIMIZATION_PROFILE = "OptimizationProfile"
 ITM_OPTIONS = "Options"
 ITM_OR = "Or"
+ITM_ORDER = "Order"
 ITM_ORIGIN = "Origin"
+ITM_ORIGINAL = "Original"
 ITM_OUTER_SIZE = "OuterSize"
 ITM_OUTPUT = "Output"
 ITM_OUTPUT_ASSIGNMENTS = "OutputAssignments"
 ITM_OUTPUT_DETECTIONS = "OutputDetections"
 ITM_OVERFLOW_POLICY = "OverflowPolicy"
+ITM_OVERLAP = "Overlap"
 ITM_OVERLAY = "Overlay"
+ITM_OVERLAY_COLOR_WITH_MONO_TEXTURE = "OverlayColorWithMonoTexture"
 ITM_OVERTEMPERATURE = "Overtemperature"
 ITM_OVERWRITE_WITH_DYNAMIC = "OverwriteWithDynamic"
 ITM_PACKETS_RESENT = "PacketsResent"
@@ -501,8 +625,11 @@ ITM_PAIRED = "Paired"
 ITM_PARAMETERS = "Parameters"
 ITM_PART_FINDER = "PartFinder"
 ITM_PART_FINDER_VIEWPOINTS = "PartFinderViewpoints"
+ITM_PARTNER = "Partner"
 ITM_PASSPHRASE = "Passphrase"
 ITM_PATCH_MATCH = "PatchMatch"
+ITM_PATCH_MATCH2 = "PatchMatch2"
+ITM_PATH = "Path"
 ITM_PATTERN = "Pattern"
 ITM_PATTERN_BUFFER = "PatternBuffer"
 ITM_PATTERN_COUNT = "PatternCount"
@@ -511,6 +638,7 @@ ITM_PATTERN_POSE = "PatternPose"
 ITM_PATTERN_TYPE = "PatternType"
 ITM_PATTERN_VOLUME = "PatternVolume"
 ITM_PATTERNS = "Patterns"
+ITM_PENALIZE = "Penalize"
 ITM_PERSISTENT_OVERLAY = "PersistentOverlay"
 ITM_PERSISTENT_PARAMETERS = "PersistentParameters"
 ITM_PHYSICS = "Physics"
@@ -519,17 +647,27 @@ ITM_PIXEL_CLOCK = "PixelClock"
 ITM_PIXEL_PITCH = "PixelPitch"
 ITM_PIXEL_SIZE = "PixelSize"
 ITM_PLANE = "Plane"
+ITM_PNP = "Pnp"
 ITM_POINT_CLOUD = "PointCloud"
 ITM_POINT_MAP = "PointMap"
 ITM_POINT_SIZE = "PointSize"
 ITM_POINTS = "Points"
 ITM_POLARITY = "Polarity"
+ITM_POP_CNT = "PopCnt"
 ITM_PORT = "Port"
 ITM_POSE = "Pose"
 ITM_POSE_ERROR = "PoseError"
 ITM_POSES = "Poses"
+ITM_POSITION = "Position"
+ITM_POST_INTERPOLATION = "PostInterpolation"
 ITM_POST_PROCESSING = "PostProcessing"
+ITM_POWER_OVER_ETHERNET = "PowerOverEthernet"
+ITM_PREFIX_LENGTH = "PrefixLength"
+ITM_PRESERVE_CALIBRATION = "PreserveCalibration"
+ITM_PRESETS = "Presets"
+ITM_PREVIEW_IMAGE = "PreviewImage"
 ITM_PRIMITIVE = "Primitive"
+ITM_PROFILER = "Profiler"
 ITM_PROGRESS = "Progress"
 ITM_PROGRESS_FACTOR = "ProgressFactor"
 ITM_PROGRESS_GRID = "ProgressGrid"
@@ -542,21 +680,29 @@ ITM_PROJECTOR_PATTERN = "ProjectorPattern"
 ITM_PROJECTOR_POWER = "ProjectorPower"
 ITM_PROJECTOR_TEMPERATURE_REACHED = "ProjectorTemperatureReached"
 ITM_PROJECTOR_WAITING_TIME = "ProjectorWaitingTime"
+ITM_PROJECTORS = "Projectors"
 ITM_PROPAGATION_DECAY = "PropagationDecay"
 ITM_PROPAGATION_LIMIT = "PropagationLimit"
 ITM_PROPAGATION_SCHEME = "PropagationScheme"
 ITM_PROTECTION = "Protection"
+ITM_QUERY_RESPONSE = "QueryResponse"
 ITM_RADIUS = "Radius"
+ITM_RANGE = "Range"
 ITM_RAW = "Raw"
 ITM_RAW_AOI_INCREMENTS = "RawAoiIncrements"
+ITM_RAW_TEXTURE = "RawTexture"
 ITM_RAY_DISTANCE_ERROR = "RayDistanceError"
+ITM_RAY_TRACING = "RayTracing"
 ITM_RECALIBRATE = "Recalibrate"
 ITM_RECTIFICATION = "Rectification"
 ITM_RECTIFIED = "Rectified"
 ITM_RECTIFIED_AOI_INCREMENTS = "RectifiedAoiIncrements"
 ITM_RECTIFIED_TEXTURE = "RectifiedTexture"
+ITM_RED = "Red"
 ITM_REDUCE = "Reduce"
 ITM_REDUCED = "Reduced"
+ITM_REFERENCE = "Reference"
+ITM_REFERENCE_DIAGONAL = "ReferenceDiagonal"
 ITM_REFINE3_D = "Refine3D"
 ITM_REFINE_COMBINED = "RefineCombined"
 ITM_REFINEMENT = "Refinement"
@@ -576,13 +722,18 @@ ITM_RENDER_GROUND_TRUTH = "RenderGroundTruth"
 ITM_RENDER_POINT_MAP = "RenderPointMap"
 ITM_RENDER_POINT_MAP_TEXTURE = "RenderPointMapTexture"
 ITM_RENDER_VIEW = "RenderView"
+ITM_RENDERED = "Rendered"
 ITM_RENDERING_MODE = "RenderingMode"
 ITM_REPROJECTION = "Reprojection"
 ITM_REPROJECTION_ERROR = "ReprojectionError"
 ITM_REPROJECTION_ERROR_SCALE = "ReprojectionErrorScale"
+ITM_REQUIRED = "Required"
 ITM_RESERVE_FACTOR = "ReserveFactor"
+ITM_RESET = "Reset"
 ITM_RESET_CLOCK = "ResetClock"
 ITM_RESIDUAL = "Residual"
+ITM_RESOLUTION = "Resolution"
+ITM_RESOLVED_LINK = "ResolvedLink"
 ITM_RESULT = "Result"
 ITM_RETRIEVED = "Retrieved"
 ITM_RETURN_ALL_PATTERN = "ReturnAllPattern"
@@ -593,22 +744,29 @@ ITM_RIGHT_TOP = "RightTop"
 ITM_ROTATE = "Rotate"
 ITM_ROTATION = "Rotation"
 ITM_RUNNING = "Running"
+ITM_RUSSIAN_ROULETTE = "RussianRoulette"
 ITM_RX = "Rx"
 ITM_RY = "Ry"
+ITM_SAMPLES = "Samples"
 ITM_SCALED_AREA_OF_INTEREST = "ScaledAreaOfInterest"
 ITM_SCALED_MEASUREMENT_VOLUME = "ScaledMeasurementVolume"
 ITM_SCALED_MINIMUM_DISPARITY = "ScaledMinimumDisparity"
 ITM_SCALED_NUMBER_OF_DISPARITIES = "ScaledNumberOfDisparities"
 ITM_SCALING = "Scaling"
 ITM_SCORE = "Score"
+ITM_SCORE_REGIONS = "ScoreRegions"
+ITM_SCREEN = "Screen"
 ITM_SEMI_GLOBAL_MATCHING = "SemiGlobalMatching"
 ITM_SENSOR = "Sensor"
 ITM_SENSORS = "Sensors"
 ITM_SERIAL_NUMBER = "SerialNumber"
+ITM_SETTINGS = "Settings"
 ITM_SETUP = "Setup"
+ITM_SEVERITY = "Severity"
 ITM_SHADOWING_THRESHOLD = "ShadowingThreshold"
 ITM_SHININESS = "Shininess"
 ITM_SHOW_CAMERAS = "ShowCameras"
+ITM_SHOW_FIELD_OF_VIEW = "ShowFieldOfView"
 ITM_SHOW_GRID = "ShowGrid"
 ITM_SHOW_NORMALS = "ShowNormals"
 ITM_SHOW_OBJECT_POINTS = "ShowObjectPoints"
@@ -620,19 +778,22 @@ ITM_SHOW_RECTIFIED_AREA = "ShowRectifiedArea"
 ITM_SHOW_SKYBOX = "ShowSkybox"
 ITM_SHOW_SURFACE = "ShowSurface"
 ITM_SHOW_USER_DEFINED_MODELS = "ShowUserDefinedModels"
+ITM_SIMILARITIES = "Similarities"
 ITM_SINK = "Sink"
 ITM_SIZE = "Size"
 ITM_SKEW = "Skew"
 ITM_SMOOTHNESS = "Smoothness"
+ITM_SNAP = "Snap"
 ITM_SOURCE = "Source"
 ITM_SPECKLE_REMOVAL = "SpeckleRemoval"
 ITM_SPECULAR = "Specular"
 ITM_SPLIT_ROTATION = "SplitRotation"
 ITM_SSID = "Ssid"
 ITM_START_DAEMON = "StartDaemon"
-ITM_STATIC_BUFFER_COUNT = "StaticBufferCount"
+ITM_STATIC_BUFFER_SIZE = "StaticBufferSize"
 ITM_STATIC_BUFFERS = "StaticBuffers"
 ITM_STATUS = "Status"
+ITM_STEPS = "Steps"
 ITM_STEREO = "Stereo"
 ITM_STEREO_CALIBRATION = "StereoCalibration"
 ITM_STEREO_CALIBRATION_ONLY = "StereoCalibrationOnly"
@@ -641,29 +802,32 @@ ITM_STEREO_INTRINSIC = "StereoIntrinsic"
 ITM_STEREO_MATCHING = "StereoMatching"
 ITM_STEREO_PATTERN_COUNT = "StereoPatternCount"
 ITM_STOP_DAEMON = "StopDaemon"
+ITM_STYLE = "Style"
 ITM_SUBSAMPLING = "Subsampling"
 ITM_SUBSET = "Subset"
 ITM_SUPPLEMENTARY = "Supplementary"
 ITM_SURFACE_CONNECTIVITY = "SurfaceConnectivity"
+ITM_SURFACE_POINTS = "SurfacePoints"
 ITM_SYMBOL = "Symbol"
+ITM_SYMMETRIES = "Symmetries"
 ITM_SYSTEM_INFO = "SystemInfo"
 ITM_T1 = "T1"
 ITM_T2 = "T2"
+ITM_TAGS = "Tags"
 ITM_TARGET = "Target"
 ITM_TARGET_BRIGHTNESS = "TargetBrightness"
 ITM_TEMPERATURE = "Temperature"
 ITM_TEMPLATE_COUNT = "TemplateCount"
+ITM_TEMPLATE_ID = "TemplateId"
 ITM_TEMPORARY = "Temporary"
 ITM_TEXT = "Text"
 ITM_TEXTURE = "Texture"
+ITM_TEXTURE_PENALTY = "TexturePenalty"
 ITM_THICKNESS = "Thickness"
 ITM_THREADS = "Threads"
 ITM_TILT_DIRECTION = "TiltDirection"
 ITM_TILTED_PATCHES = "TiltedPatches"
 ITM_TIME = "Time"
-ITM_TIME_EXECUTE = "TimeExecute"
-ITM_TIME_FINALIZE = "TimeFinalize"
-ITM_TIME_PREPARE = "TimePrepare"
 ITM_TIMEOUT = "Timeout"
 ITM_TIMESTAMP = "Timestamp"
 ITM_TOLERANCE = "Tolerance"
@@ -681,7 +845,9 @@ ITM_U_EYE = "UEye"
 ITM_USB = "USB"
 ITM_UNIQUENESS_OFFSET = "UniquenessOffset"
 ITM_UNIQUENESS_RATIO = "UniquenessRatio"
+ITM_UNKNOWN = "Unknown"
 ITM_UNSAFE = "Unsafe"
+ITM_UP_VECTOR = "UpVector"
 ITM_UPDATE_GLOBAL_PATTERN_DATA = "UpdateGlobalPatternData"
 ITM_UPDATER = "Updater"
 ITM_URL = "Url"
@@ -706,14 +872,19 @@ ITM_VALUES = "Values"
 ITM_VERGENCE = "Vergence"
 ITM_VERSION = "Version"
 ITM_VERTICAL = "Vertical"
+ITM_VIEW = "View"
 ITM_VIEW_POSE = "ViewPose"
+ITM_VIEWPOINT_COUNT = "ViewpointCount"
 ITM_VIEWPOINT_INDEX = "ViewpointIndex"
 ITM_VIEWPOINTS = "Viewpoints"
 ITM_VIGNETTING = "Vignetting"
 ITM_VIRTUAL = "Virtual"
+ITM_VISIBLE = "Visible"
+ITM_VISUALIZATION = "Visualization"
 ITM_WAIT_FOR = "WaitFor"
 ITM_WAIT_FOR_PROJECTOR = "WaitForProjector"
 ITM_WAIT_FOR_RECALIBRATION = "WaitForRecalibration"
+ITM_WHITE_BALANCE = "WhiteBalance"
 ITM_WIDTH = "Width"
 ITM_WIFI = "Wifi"
 ITM_WINDOW_RADIUS = "WindowRadius"
@@ -721,11 +892,16 @@ ITM_WIRING_TEST = "WiringTest"
 ITM_WITH_OVERLAY = "WithOverlay"
 ITM_WORLD_COORDINATES = "WorldCoordinates"
 ITM_WRITE_FREQUENCY = "WriteFrequency"
+ITM_X = "X"
+ITM_Y = "Y"
 ITM_YEAR = "Year"
 ITM_YELLOW = "Yellow"
+ITM_Z = "Z"
 ITM_Z_BUFFER_ONLY = "ZBufferOnly"
+ITM_ZOOM = "Zoom"
+VAL_ABB = "ABB"
 VAL_ACCESS_POINT = "AccessPoint"
-VAL_ADD = "Add"
+VAL_ADEPT = "Adept"
 VAL_ALIGNED = "Aligned"
 VAL_ALIGNED_AND_DIAGONAL = "AlignedAndDiagonal"
 VAL_ALL = "All"
@@ -743,10 +919,13 @@ VAL_BOTTOM = "Bottom"
 VAL_BOX = "Box"
 VAL_BOXES = "Boxes"
 VAL_BUFFER = "Buffer"
+VAL_CALIBRATION = "Calibration"
 VAL_CAMERA_Z = "CameraZ"
+VAL_CIRCLES = "Circles"
 VAL_CLEAR_NETWORK = "ClearNetwork"
 VAL_CLIENT = "Client"
 VAL_CLOSE_ACCESS_POINT = "CloseAccessPoint"
+VAL_COMAU = "Comau"
 VAL_CONFIRM = "Confirm"
 VAL_CONNECT = "Connect"
 VAL_CONNECTED = "Connected"
@@ -761,44 +940,60 @@ VAL_DEBUG = "Debug"
 VAL_DEBUG_OUT = "DebugOut"
 VAL_DELAYED = "Delayed"
 VAL_DELETE_MODEL = "DeleteModel"
+VAL_DEVELOPMENT = "Development"
 VAL_DIAGONAL = "Diagonal"
 VAL_DISABLED = "Disabled"
 VAL_DISCARD_NEW = "DiscardNew"
 VAL_DISCARD_OLD = "DiscardOld"
 VAL_DISCONNECT = "Disconnect"
 VAL_DISCONNECTED = "Disconnected"
+VAL_DOOSAN = "Doosan"
 VAL_DOWN = "Down"
 VAL_ENABLED = "Enabled"
 VAL_ENSENSO = "Ensenso"
+VAL_EPSON = "Epson"
+VAL_ERROR = "Error"
 VAL_ETHERNET = "Ethernet"
 VAL_EUCLIDEAN = "Euclidean"
 VAL_FACTORY_RESET = "FactoryReset"
 VAL_FALLING_EDGE = "FallingEdge"
+VAL_FANUC = "Fanuc"
 VAL_FILE = "File"
 VAL_FIND = "Find"
+VAL_FIRMWARE_UPDATE = "FirmwareUpdate"
 VAL_FIXED = "Fixed"
 VAL_FLEX_VIEW2 = "FlexView2"
+VAL_FLEX_VIEW3 = "FlexView3"
 VAL_FLEXIBLE = "Flexible"
 VAL_FLOAT = "Float"
 VAL_FORCE = "Force"
+VAL_FRUITCORE = "Fruitcore"
 VAL_GENERATE_MODEL = "GenerateModel"
 VAL_GET_MODEL_DISTANCE = "GetModelDistance"
+VAL_GREEDY_OBJECT_MATCHING = "GreedyObjectMatching"
 VAL_GRID_HEIGHT = "GridHeight"
 VAL_GRID_SPACING = "GridSpacing"
 VAL_GRID_WIDTH = "GridWidth"
 VAL_HALCON = "Halcon"
 VAL_HAND = "Hand"
+VAL_HARDWARE = "Hardware"
 VAL_HIDDEN = "Hidden"
 VAL_HIGH = "High"
 VAL_HIGH_ACTIVE = "HighActive"
 VAL_IGNORE = "Ignore"
 VAL_IMAGE_POSITION = "ImagePosition"
+VAL_IMAGE_SENSOR = "ImageSensor"
 VAL_IMMEDIATE = "Immediate"
 VAL_IN_USE = "InUse"
 VAL_INDEX = "Index"
+VAL_INFERNO = "Inferno"
 VAL_INFO = "Info"
 VAL_INPUT = "Input"
+VAL_INTERNAL = "Internal"
 VAL_ITEM = "Item"
+VAL_JET = "Jet"
+VAL_KAWASAKI = "Kawasaki"
+VAL_KUKA = "Kuka"
 VAL_LEFT = "Left"
 VAL_LEFT_TO_RIGHT = "LeftToRight"
 VAL_LINK = "Link"
@@ -810,12 +1005,17 @@ VAL_LOCAL = "Local"
 VAL_LOCKED = "Locked"
 VAL_LOW = "Low"
 VAL_LOW_ACTIVE = "LowActive"
+VAL_MAGMA = "Magma"
 VAL_MASK = "Mask"
+VAL_MECADEMIC = "Mecademic"
 VAL_MESH = "Mesh"
 VAL_MIRROR_FLASH_OUTPUT = "MirrorFlashOutput"
+VAL_MITSUBISHI = "Mitsubishi"
 VAL_MONOCULAR = "Monocular"
 VAL_MOVING = "Moving"
-VAL_NEW = "New"
+VAL_MULTI_VIEW = "MultiView"
+VAL_NACHI = "Nachi"
+VAL_NETWORK_CONFIGURATION = "NetworkConfiguration"
 VAL_NONE = "None"
 VAL_NORMAL = "Normal"
 VAL_NOT_SPECIFIED = "NotSpecified"
@@ -827,33 +1027,43 @@ VAL_OPEN = "Open"
 VAL_OPEN_ACCESS_POINT = "OpenAccessPoint"
 VAL_ORIGIN = "Origin"
 VAL_PWM = "PWM"
+VAL_PAIRING = "Pairing"
 VAL_PATCH_MATCH = "PatchMatch"
+VAL_PATCH_MATCH2 = "PatchMatch2"
 VAL_PATTERN = "Pattern"
 VAL_PERSISTENT = "Persistent"
+VAL_PIVOT = "Pivot"
 VAL_PLANE = "Plane"
+VAL_PLASMA = "Plasma"
 VAL_POINTS = "Points"
+VAL_PREVIEW = "Preview"
 VAL_PROJECTOR = "Projector"
 VAL_RANDOM = "Random"
 VAL_RAW = "Raw"
 VAL_RECTIFIED = "Rectified"
 VAL_REMOTE = "Remote"
 VAL_REPROJECTION_ERROR = "ReprojectionError"
+VAL_RESERVE_LICENSE = "ReserveLicense"
+VAL_RESOLVED_LINK = "ResolvedLink"
 VAL_RIGHT = "Right"
 VAL_RIGHT_TO_LEFT = "RightToLeft"
 VAL_RISING_EDGE = "RisingEdge"
 VAL_SCAN = "Scan"
 VAL_SCANNING = "Scanning"
+VAL_SEMI_GLOBAL_MATCHING = "SemiGlobalMatching"
 VAL_SERIAL_NUMBER = "SerialNumber"
 VAL_SGM_ALIGNED = "SgmAligned"
 VAL_SGM_ALIGNED_AND_DIAGONAL = "SgmAlignedAndDiagonal"
 VAL_SGM_DIAGONAL = "SgmDiagonal"
 VAL_SGM_SINGLE_PASS = "SgmSinglePass"
+VAL_SIMULATION = "Simulation"
 VAL_SINGLE = "Single"
 VAL_SINGLE_CUSTOM = "SingleCustom"
 VAL_SOFTWARE = "Software"
 VAL_SPHERE = "Sphere"
 VAL_SPHERES = "Spheres"
 VAL_SQUARES = "Squares"
+VAL_STAEUBLI = "Staeubli"
 VAL_STANDARD = "Standard"
 VAL_STATIC = "Static"
 VAL_STEREO = "Stereo"
@@ -864,11 +1074,13 @@ VAL_STRUCTURE_LOCKED = "StructureLocked"
 VAL_STRUCTURED_LIGHT = "StructuredLight"
 VAL_SUCCESSFUL = "Successful"
 VAL_T_PIECE = "TPiece"
+VAL_TECHMAN = "Techman"
 VAL_TEXTURE = "Texture"
 VAL_TILT_DIRECTION = "TiltDirection"
 VAL_TOP = "Top"
 VAL_TRACE = "Trace"
 VAL_TRIGGERED = "Triggered"
+VAL_TWILIGHT = "Twilight"
 VAL_TYPE = "Type"
 VAL_USB = "USB"
 VAL_UNIFORM = "Uniform"
@@ -878,7 +1090,11 @@ VAL_UP = "Up"
 VAL_UPDATE_ACCESS_POINT = "UpdateAccessPoint"
 VAL_USER_DATA = "UserData"
 VAL_VALIDATE = "Validate"
+VAL_VIEWER = "Viewer"
+VAL_VIRIDIS = "Viridis"
 VAL_VIRTUAL = "Virtual"
+VAL_VISUALIZE_MODEL = "VisualizeModel"
+VAL_WARNING = "Warning"
 VAL_WORKSPACE = "Workspace"
 VAL_WORLD_Z = "WorldZ"
 VAL_WPA2_PSK = "Wpa2Psk"
@@ -891,17 +1107,19 @@ VAL_Y = "Y"
 VAL_Y_NEGATIVE = "YNegative"
 VAL_Y_POSITIVE = "YPositive"
 VAL_Y_ROTATION_SYMMETRIC = "YRotationSymmetric"
+VAL_YASKAWA = "Yaskawa"
 VAL_Z = "Z"
 VAL_Z_NEGATIVE = "ZNegative"
 VAL_Z_POSITIVE = "ZPositive"
 VAL_Z_ROTATION_SYMMETRIC = "ZRotationSymmetric"
 VAL_ZYX = "ZYX"
+VAL_ZYZ = "ZYZ"
 NX_ERRORS = [
     "NxLibOperationSucceeded",
-    "NxLibCannotCreateItem",
+    "NxLibItemProtected",
     "NxLibCouldNotInterpretJsonText",
     "NxLibItemInexistent",
-    "",
+    "NxLibItemPathInvalid",
     "NxLibNoDebugData",
     "NxLibCouldNotOpenPort",
     "NxLibInternalError",
@@ -909,7 +1127,7 @@ NX_ERRORS = [
     "NxLibNotConnected",
     "NxLibMethodInvalid",
     "NxLibBadRequest",
-    "",
+    "NxLibItemMaximumUniqueCountReached",
     "NxLibItemTypeNotCompatible",
     "NxLibInvalidBufferSize",
     "NxLibBufferTooSmall",
@@ -924,36 +1142,42 @@ NX_ERRORS = [
     "NxLibNestingLimitReached",
     "NxLibNoOpenProfileBlock",
     "NxLibLibraryAlreadyLoaded",
+    "NxLibOperationCanceled",
+    "NxLibInvalidParameters",
 ]
-NXLIB_BAD_REQUEST = 11
-NXLIB_BUFFER_NOT_DIVISIBLE_BY_ELEMENT_SIZE = 16
-NXLIB_BUFFER_TOO_SMALL = 15
-NXLIB_CANNOT_CREATE_ITEM = 1
-NXLIB_COMMAND_RUNNING = 19
-NXLIB_CONNECTION_NOT_COMPATIBLE = 22
-NXLIB_COULD_NOT_INTERPRET_JSON_TEXT = 2
-NXLIB_COULD_NOT_LOAD_FUNCTION = 21
-NXLIB_COULD_NOT_LOAD_LIBRARY = 20
-NXLIB_COULD_NOT_OPEN_PORT = 6
-NXLIB_DEBUG_MESSAGE_OVERFLOW = 18
-NXLIB_EXECUTION_FAILED = 17
-NXLIB_INITIALIZATION_NOT_ALLOWED = 23
-NXLIB_INTERNAL_ERROR = 7
-NXLIB_INVALID_BUFFER_SIZE = 14
-NXLIB_ITEM_INEXISTENT = 3
-NXLIB_ITEM_TYPE_NOT_COMPATIBLE = 13
-NXLIB_LIBRARY_ALREADY_LOADED = 26
-NXLIB_METHOD_INVALID = 10
-NXLIB_NESTING_LIMIT_REACHED = 24
-NXLIB_NO_DEBUG_DATA = 5
-NXLIB_NO_OPEN_PROFILE_BLOCK = 25
-NXLIB_NOT_CONNECTED = 9
 NXLIB_OPERATION_SUCCEEDED = 0
+NXLIB_ITEM_PROTECTED = 1
+NXLIB_COULD_NOT_INTERPRET_JSON_TEXT = 2
+NXLIB_ITEM_INEXISTENT = 3
+NXLIB_ITEM_PATH_INVALID = 4
+NXLIB_NO_DEBUG_DATA = 5
+NXLIB_COULD_NOT_OPEN_PORT = 6
+NXLIB_INTERNAL_ERROR = 7
 NXLIB_TIMEOUT = 8
-NXLIB_ITEM_TYPE_ARRAY = 5
-NXLIB_ITEM_TYPE_BOOL = 4
+NXLIB_NOT_CONNECTED = 9
+NXLIB_METHOD_INVALID = 10
+NXLIB_BAD_REQUEST = 11
+NXLIB_ITEM_MAXIMUM_UNIQUE_COUNT_REACHED = 12
+NXLIB_ITEM_TYPE_NOT_COMPATIBLE = 13
+NXLIB_INVALID_BUFFER_SIZE = 14
+NXLIB_BUFFER_TOO_SMALL = 15
+NXLIB_BUFFER_NOT_DIVISIBLE_BY_ELEMENT_SIZE = 16
+NXLIB_EXECUTION_FAILED = 17
+NXLIB_DEBUG_MESSAGE_OVERFLOW = 18
+NXLIB_COMMAND_RUNNING = 19
+NXLIB_COULD_NOT_LOAD_LIBRARY = 20
+NXLIB_COULD_NOT_LOAD_FUNCTION = 21
+NXLIB_CONNECTION_NOT_COMPATIBLE = 22
+NXLIB_INITIALIZATION_NOT_ALLOWED = 23
+NXLIB_NESTING_LIMIT_REACHED = 24
+NXLIB_NO_OPEN_PROFILE_BLOCK = 25
+NXLIB_LIBRARY_ALREADY_LOADED = 26
+NXLIB_OPERATION_CANCELED = 27
+NXLIB_INVALID_PARAMETERS = 28
 NXLIB_ITEM_TYPE_INVALID = 0
 NXLIB_ITEM_TYPE_NULL = 1
 NXLIB_ITEM_TYPE_NUMBER = 2
-NXLIB_ITEM_TYPE_OBJECT = 6
 NXLIB_ITEM_TYPE_STRING = 3
+NXLIB_ITEM_TYPE_BOOL = 4
+NXLIB_ITEM_TYPE_ARRAY = 5
+NXLIB_ITEM_TYPE_OBJECT = 6
